:: Jesse Gonzales
:: Principal Technical Educational Consultant
:: Endpoint Management
:: Symantec Corporation, 2014
:: If you have installed the Symantec Workspace Virtualization plugin
:: and have prepared the image for capture using MS Sysprep or Symantec Deployment
:: Solution, each computer's registry containing the volume GUID for
:: DefaultFileRedirect will need to be updated with the volume's current GUID.
:: This script will check to see if Symantec Workspace Virtualization is first installed.
:: If the SWV agent is not installed, the script will exit.
:: If SWV is installed, the script will check the value in the registry exists.
:: If the value exists, then it will be compared to the volume GUID.
:: If the volume GUID differs from the registry value, the registry value will be updated.
:: If the registry entry does not exist and SWV is installed, the script will exit. 
:: If SWV is installed and an error occurs in the comparison, the script will exit.
:: THIS SCRIPT WILL ONLY WORK IF THE SYMANTEC MANAGEMENT AGENT AND SYMANTEC WORKSPACE
:: VIRTUALIZATION AGENT ARE INSTALLED ON C.

CLS
ECHO OFF
:: Set Variables for the script
:: VolGUID will be populated with the GUID of c:.
:: HKLMvar will contain the path in the registry we will check
FOR /f "tokens=*" %%G IN ('mountvol.exe c: /L') DO SET VolGUID=%%G
SET HKLMvar=HKLM\SYSTEM\CurrentControlSet\services\FSLX\Parameters\FSL
SET RegText=DefaultFileRedirect    REG_SZ    
SET CompareText=%VolGUID%fslrdr

:: Check key if exists in the registry
REG QUERY %HKLMvar% /v DefaultFileRedirect
IF errorlevel==0 GOTO COMPARE
IF errorlevel==1 GOTO ERROR
IF errorlevel==2 GOTO CHANGE

:COMPARE
::Check to see if key is proper
FOR /f "tokens=3" %%G IN ('REG QUERY %HKLMvar% /v DefaultFileRedirect') DO SET HKLMreg=%%G
IF %HKLMreg%==%CompareText% GOTO NOCHANGE
IF %HKLMreg% NEQ %CompareText% GOTO CHANGE
else ERROR

:NOCHANGE
SET EXITmessage=No Change is required
GOTO END

:ERROR
SET EXITmessagecode=An error has occured
GOTO END

:CHANGE
REG ADD %HKLMvar% /v DefaultFileRedirect /t REG_SZ /d ^%VolGUID%^fslrdr /f
SET EXITmessage=The registry value, DefaultFileRedirect, has been updated with the following value %VolGUID%fslrdr
GOTO END

:END
::ECHO %EXITmessage%
EXIT

